{#
  Copyright (C) 2023 Graz University of Technology

  invenio-records-global-search is free software; you can redistribute it and/or modify
  it under the terms of the MIT License; see LICENSE file for more details.
#}
{%- extends config.GLOBAL_SEARCH_BASE_TEMPLATE %}

{%- block javascript %}
{{ super() }}
{{ webpack['invenio-records-global-search-search.js'] }}
{%- endblock %}

{%- block page_body %}

<div class="ui container">
  <div id="invenio-search-global-search-config"
       data-invenio-search-config='{{ search_app_global_search_config() | tojson }}'></div>
</div>

{%- endblock page_body %}
