{# -*- coding: utf-8 -*-

  This file is part of Invenio.

  Copyright (C) 2023 Graz University of Technology.

  invenio-records-global-search is free software; you can redistribute it and/or
  modify it under the terms of the MIT License; see LICENSE file for more
  details.
#}


{%- extends config.BASE_TEMPLATE %}

{%- block css %}
{{ super() }}
{{ webpack['invenio-records-global-search-theme.css'] }}
{%- endblock css %}
